@@ -13,6 +13,19 @@ def _get_in_urls(
     }
 
 
+class MissedInsParameters(Exception):
+    def __init__(self, missed_vars, op_parameters_ins):
+        keys_str = '/n'.join(missed_vars)
+        self.message = f"""
+        variables with keys:
+        {keys_str}
+        from dict in cell 'op_parameters'
+        {op_parameters_ins}
+        must be declared in cell 'parameters'
+        """
+        super().__init__(self.message)
+
+
 class StorageCatalogABC(ABC):
     @property
     @abstractmethod
@@ -46,4 +59,8 @@ class StorageCatalogABC(ABC):
         local_vars = locals() # Local symbol Table
         'ins': {'key': 'nb_data1'} -> {key: local_vars['nb_data1']}
         """
-        return _get_in_urls(local_vars, op_parameters_ins)
+        urls_dict = _get_in_urls(local_vars, op_parameters_ins)
+        empty_vals = [k for k, url in urls_dict.items() if not url]
+        if len(empty_vals) > 0:
+            raise MissedInsParameters(empty_vals, op_parameters_ins)
+        return urls_dict
